@@ -1,6 +1,6 @@
 /*
     This file is part of the KContacts framework.
-    Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
+    Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -28,9 +28,7 @@
  *  @since 4.14.5
  */
 
-namespace KContacts
-{
-
+namespace KContacts {
 class KCONTACTS_EXPORT Gender
 {
     friend KCONTACTS_EXPORT QDataStream &operator<<(QDataStream &, const Gender &);
