@@ -1,6 +1,6 @@
 /*
     This file is part of the KContacts framework.
-    Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
+    Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -29,8 +29,7 @@
 /** @short Class that holds a Organization for a contact.
  *  @since 5.3
  */
-namespace KContacts
-{
+namespace KContacts {
 class KCONTACTS_EXPORT Org
 {
     friend KCONTACTS_EXPORT QDataStream &operator<<(QDataStream &, const Org &);
@@ -65,7 +64,6 @@ private:
 KCONTACTS_EXPORT QDataStream &operator<<(QDataStream &stream, const Org &object);
 
 KCONTACTS_EXPORT QDataStream &operator>>(QDataStream &stream, Org &object);
-
 }
 Q_DECLARE_TYPEINFO(KContacts::Org, Q_MOVABLE_TYPE);
 #endif // ORG_H
